@@ -11,26 +11,28 @@ User = get_user_model()
 
 class UserAdmin(admin.ModelAdmin):
     list_display = (
+        "id",
         "username",
-        "keycloak_id",
         "is_staff",
         "is_superuser",
     )
     fields = [
         "username",
         "keycloak_link",
+        "email",
+        "first_name",
+        "last_name",
         "is_staff",
         "is_superuser",
         "is_active",
     ]
-    readonly_fields = ["keycloak_link"]
+    readonly_fields = ["keycloak_link", "email", "first_name", "last_name"]
 
     def keycloak_link(self, obj):
         config = settings.KEYCLOAK_CONFIG
-        label = obj.keycloak_id
+        label = obj.id
         link = KEYCLOAK_ADMIN_USER_PAGE.format(
-            host=config.get("SERVER_URL"), realm=config.get("REALM"), keycloak_id=label
-        )
+            host=config.get("SERVER_URL"), realm=config.get("REALM"), id=label)
         return format_html('<a href="{link}" target="_blank">{label}</a>', link=link, label=label)
 
     keycloak_link.short_description = _("keycloak link")
